@@ -52,13 +52,15 @@ class DepremOCR:
         return total_text
 
     def __download_models(self):
-        det_model_path = "ch_PP-OCRv3_det_infer"
+        PROJECT_ROOT = os.path.dirname(os.path.abspath(__file__))
+
+        det_model_path = os.path.join(PROJECT_ROOT, "ch_PP-OCRv3_det_infer.tar")
         if not os.path.exists(det_model_path):
             det_model_url = "https://paddleocr.bj.bcebos.com/PP-OCRv3/chinese/ch_PP-OCRv3_det_infer.tar"
             self.__download_file(det_model_path, det_model_url)
             self.__extract_tar(det_model_path)
 
-        rec_model_path = "ch_PP-OCRv3_rec_infer"
+        rec_model_path = os.path.join(PROJECT_ROOT, "ch_PP-OCRv3_rec_infer.tar")
         if not os.path.exists(rec_model_path):
             rec_model_url = "https://paddleocr.bj.bcebos.com/PP-OCRv3/chinese/ch_PP-OCRv3_rec_infer.tar"
             self.__download_file(rec_model_path, rec_model_url)
@@ -71,7 +73,7 @@ class DepremOCR:
                 f.write(response.raw.read())
 
     def __extract_tar(self, path: str):
-        model_tar = tarfile.open(path+".tar")
+        model_tar = tarfile.open(path)
         model_tar.extractall('./')
         model_tar.close()
         
